@@ -21,7 +21,7 @@ else:
     _open = open
     from urllib.parse import urlparse
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 _is_sphinx = False
 prolog = '''\
 .. role:: raw-html-m2r(raw)
@@ -47,6 +47,9 @@ parser.add_argument('--parse-relative-links', action='store_true',
 parser.add_argument('--anonymous-references', action='store_true',
                     default=False,
                     help='use anonymous references in generated rst')
+parser.add_argument('--disable-inline-math', action='store_true',
+                    default=False,
+                    help='disable parsing inline math')
 
 
 def parse_options():
@@ -131,19 +134,27 @@ class RestInlineLexer(mistune.InlineLexer):
         'image_link',
         'rest_role',
         'rest_link',
-        'inline_math',
         'eol_literal_marker',
     ] + mistune.InlineLexer.default_rules
 
     def __init__(self, *args, **kwargs):
         no_underscore_emphasis = kwargs.pop('no_underscore_emphasis', False)
+        disable_inline_math = kwargs.pop('disable_inline_math', False)
         super(RestInlineLexer, self).__init__(*args, **kwargs)
-        if no_underscore_emphasis:
-            self.rules.no_underscore_emphasis()
-        elif not _is_sphinx:
+        if not _is_sphinx:
             parse_options()
-            if options.no_underscore_emphasis:
-                self.rules.no_underscore_emphasis()
+        if no_underscore_emphasis or getattr(options,
+                                             'no_underscore_emphasis',
+                                             False):
+            self.rules.no_underscore_emphasis()
+        inline_maths = 'inline_math' in self.default_rules
+        if disable_inline_math or getattr(options,
+                                          'disable_inline_math',
+                                          False):
+            if inline_maths:
+                self.default_rules.remove('inline_math')
+        elif not inline_maths:
+            self.default_rules.insert(0, 'inline_math')
 
     def output_double_emphasis(self, m):
         # may include code span
@@ -198,9 +209,9 @@ class RestRenderer(mistune.Renderer):
         super(RestRenderer, self).__init__(*args, **kwargs)
         if not _is_sphinx:
             parse_options()
-            if options.parse_relative_links:
+            if getattr(options, 'parse_relative_links', False):
                 self.parse_relative_links = options.parse_relative_links
-            if options.anonymous_references:
+            if getattr(options, 'anonymous_references', False):
                 self.anonymous_references = options.anonymous_references
 
     def _indent_block(self, block):
@@ -405,7 +416,7 @@ class RestRenderer(mistune.Renderer):
                         # Example: [text](#anchor)
                         link_type = 'ref'
                 doc_link = '{doc_name}{anchor}'.format(
-                    # splitext approach works whether or not path is set. It
+                    # splittext approach works whether or not path is set. It
                     # will return an empty string if unset, which leads to
                     # anchor only ref.
                     doc_name=os.path.splitext(url_info.path)[0],
@@ -548,6 +559,7 @@ class M2RParser(rst.Parser, object):
             no_underscore_emphasis=config.no_underscore_emphasis,
             parse_relative_links=config.m2r_parse_relative_links,
             anonymous_references=config.m2r_anonymous_references,
+            disable_inline_math=config.m2r_disable_inline_math
         )
         super(M2RParser, self).parse(converter(inputstring), document)
 
@@ -555,7 +567,7 @@ class M2RParser(rst.Parser, object):
 class MdInclude(rst.Directive):
     """Directive class to include markdown in sphinx.
 
-    Load a file and convert it to rst and insert as a node. Currentlly
+    Load a file and convert it to rst and insert as a node. Currently
     directive-specific options are not implemented.
     """
     required_arguments = 1
@@ -587,7 +599,7 @@ class MdInclude(rst.Directive):
         tab_width = self.options.get(
             'tab-width', self.state.document.settings.tab_width)
 
-        # open the inclding file
+        # open the including file
         try:
             self.state.document.settings.record_dependencies.add(path)
             include_file = io.FileInput(source_path=path,
@@ -620,6 +632,7 @@ class MdInclude(rst.Directive):
             no_underscore_emphasis=config.no_underscore_emphasis,
             parse_relative_links=config.m2r_parse_relative_links,
             anonymous_references=config.m2r_anonymous_references,
+            disable_inline_math=config.m2r_disable_inline_math
         )
         include_lines = statemachine.string2lines(converter(rawtext),
                                                   tab_width,
@@ -629,12 +642,13 @@ class MdInclude(rst.Directive):
 
 
 def setup(app):
-    """When used for spinx extension."""
+    """When used for sphinx extension."""
     global _is_sphinx
     _is_sphinx = True
     app.add_config_value('no_underscore_emphasis', False, 'env')
     app.add_config_value('m2r_parse_relative_links', False, 'env')
     app.add_config_value('m2r_anonymous_references', False, 'env')
+    app.add_config_value('m2r_disable_inline_math', False, 'env')
     app.add_source_parser('.md', M2RParser)
     app.add_directive('mdinclude', MdInclude)
     metadata = dict(
